/**
*****************************************************************************
**
**  File        : main.c
**
**  Abstract    : main function.
**
**  Functions   : main
**
**  Environment : Atollic TrueSTUDIO/STM32
**                STMicroelectronics STM32F105RB Standard Peripherals Library
**
**  Distribution: The file is distributed as is, without any warranty
**                of any kind.
**
**
**  (c)Copyright C. Hediger
**  www.endasmedia.ch
**  Date: 08.01.2011
**
**
*****************************************************************************
*/

/* Includes */
#include <stddef.h>
#include "stm32f10x.h"

#include "config.h"		// hier werden alle noetigen konfigurationen vorgenommen !
#include "mmc.h"		// hardware abhaengig
#include "file.h"
#include "fat.h"

void RCC_Configuration(void);
void GPIO_Configuration(void);

ErrorStatus HSEStartUpStatus;

unsigned char Buffer [512];

int main(void)
{
	RCC_Configuration();
	GPIO_Configuration();

	while (FALSE==mmc_init()){
			nop();
		}


	if(TRUE == fat_loadFatData()){

		  // Wenn auf dem terminal "Boot... OK" zu lesen ist, ist Init OK.
		  // Jetzt kann man schreiben/anhaengen/lesen.
		  //uputs((unsigned char*)"Ok\n");



		  // Dateinamen muessen in diesem Format sein !
		  // Man beachte die Gre des Arrays und die Grobuchstaben!
		  unsigned char file_name[9]="test.txt";

		  // String zum in die Datei schreiben.
		  unsigned char str[13]="Hallo Datei!";






		  // Datei existiert nicht, also anlegen !
		  if(MMC_FILE_NEW == ffopen(file_name)){

		     // Schreibt String auf Karte !
		     // Nur richtige Strings koennen mit ffwrites geschrieben werden !
		     ffwrites(str);

		     // Neue Zeile in der Datei.
	             // Schreibt Zeilenumbruch in die Text Datei.
		     ffwrite(0x0D);
		     ffwrite(0x0A);

		     // Schliet Datei.
		     ffclose();
		   }




		  // Datei existiert, also anhaengen !
		  if(MMC_FILE_EXISTS == ffopen(file_name)){

		     // Spult bis zum Dateiende vor um anzuhaengen, geht auch ohne Option MMC_OVER_WRITE !
		     ffseek(file.length);

		     // Schreibt String.
		     ffwrites(str);

		     // Neue Zeile in der Datei.
	             // Schreibt Zeilenumbruch in die Text Datei.
		     ffwrite(0x0D);
		     ffwrite(0x0A);

		     // Schliet Datei.
		     ffclose();
		   }

	}


	while(1)
	{

	}



}





void RCC_Configuration(void)
{
  /* RCC system reset(for debug purpose) */
  RCC_DeInit();
  /* Enable HSE */
  RCC_HSEConfig(RCC_HSE_ON);
  /* Wait till HSE is ready */
  HSEStartUpStatus = RCC_WaitForHSEStartUp();

  if(HSEStartUpStatus == SUCCESS)
  {
    /* Enable Prefetch Buffer */
    FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);
    /* Flash 2 wait state */
    FLASH_SetLatency(FLASH_Latency_2);
    /* HCLK = SYSCLK */
    RCC_HCLKConfig(RCC_SYSCLK_Div1);
    /* PCLK2 = HCLK */
    RCC_PCLK2Config(RCC_HCLK_Div1);
    /* PCLK1 = HCLK/2 */
    RCC_PCLK1Config(RCC_HCLK_Div2);
    /* ADCCLK = PCLK2/4 */
    RCC_ADCCLKConfig(RCC_PCLK2_Div4);

    /* Configure PLLs *********************************************************/
    /* PLL2 configuration: PLL2CLK = (HSE (8MHz) / 10) * 20 = 40 MHz */
    RCC_PREDIV2Config(RCC_PREDIV2_Div4);
    RCC_PLL2Config(RCC_PLL2Mul_10);

    /* Enable PLL2 */
    RCC_PLL2Cmd(ENABLE);

    /* Wait till PLL2 is ready */
    while (RCC_GetFlagStatus(RCC_FLAG_PLL2RDY) == RESET)
    {}

    /* PLL configuration: PLLCLK = (8MHz HSE) * 9 = 72 MHz */
    RCC_PREDIV1Config(RCC_PREDIV1_Source_HSE, RCC_PREDIV1_Div1);
    RCC_PLLConfig(RCC_PLLSource_PREDIV1, RCC_PLLMul_9);

    /* PPL3 configuration: PLL3CLK = (HSE / 5) * 11 = PLL3_VCO = 110 MHz */
    RCC_PLL3Config(RCC_PLL3Mul_12);
    /* Enable PLL3 */
    RCC_PLL3Cmd(ENABLE);
    /* Wait till PLL3 is ready */
    while (RCC_GetFlagStatus(RCC_FLAG_PLL3RDY) == RESET)
    {}

    /* Enable PLL */
    RCC_PLLCmd(ENABLE);
    /* Wait till PLL is ready */
    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);
    /* Select PLL as system clock source */
    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK); //72MHz
    /* Wait till PLL is used as system clock source */
    while(RCC_GetSYSCLKSource() != 0x08);
  }

  /* Enable peripheral clocks --------------------------------------------------*/
  /* GPIOA, GPIOB and AFIO clocks enable */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE);

}


void GPIO_Configuration(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;


								//Clock Out,  SCK, MISO, MOSI
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_9 | GPIO_Pin_12 | GPIO_Pin_11;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
								//DO
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_10;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;
  GPIO_Init(GPIOA, &GPIO_InitStructure);

}


/*
 * Minimal __assert_func used by the assert() macro
 * */
void __assert_func(const char *file, int line, const char *func, const char *failedexpr)
{
  while(1)
  {}
}

/*
 * Minimal __assert() uses __assert__func()
 * */
void __assert(const char *file, int line, const char *failedexpr)
{
   __assert_func (file, line, NULL, failedexpr);
}
